@@ -7,20 +7,53 @@ def remove_bg():
     except IndexError:
         exit('Usage: qs -rmbg picture')
     else:
+        if path == '-help':
+            print('Usage: qs -rmbg picture')
+            return
         from QuickStart_Rhy.API.simple_api import rmbg
         rmbg(path)
 
 
-def ImgBed():
+def smms():
     try:
         path = sys.argv[2]
     except IndexError:
-        exit('Usage: qs -smms [picture]')
+        exit('Usage: qs -smms [picture | *.md]')
     else:
+        if path == '-help':
+            print('Usage: qs -smms [picture | *.md]')
+            return
         from QuickStart_Rhy.API.simple_api import smms
         smms(path)
 
 
+def up_img():
+    try:
+        path = sys.argv[2]
+    except IndexError:
+        exit('Usage: qs -upimg [picture]')
+    else:
+        from QuickStart_Rhy.API.simple_api import upimg
+        import random
+        spt_type = {'Ali': '阿里云', 'Sogou': '搜狗', 'Vimcn': 'Vim-cn.com', 'Niupic': '牛图', 'Juejin': '掘进',
+                    'UploadLiu': 'upload.ouliu.net', 'Catbox': 'catbox', 'NetEasy': '网易', 'Prnt': 'Prnt',
+                    'Qihoo': '360奇虎', 'Souhu': '搜狐', 'Toutiao': '头条', 'Xiaomi': '小米', 'ImgTg': 'imt.tg'}
+        spt_type_keys = list(spt_type.keys())
+        if path == '-help':
+            print('Usage: qs -upimg <picture | *.md> [platform]\n\nSupport ([platform]: description):')
+            print(''.join(['%-10s: %s%s' % (spt_type_keys[i], spt_type[spt_type_keys[i]], '\t' if (i + 1) % 3 else '\n')
+                           for i in range(len(spt_type_keys))]))
+            print('\n[NOTE] If you do not set platform, qs will randomly choose one.')
+            return
+        type_map = {}
+        for i in spt_type:
+            type_map[i.lower()] = i
+            type_map[i] = i
+        upimg(path, type_map[sys.argv[3]]) if len(sys.argv) > 3 and sys.argv[3] in type_map \
+            else upimg(path, random.choice(spt_type_keys)), \
+            print('No such platform: %s' % sys.argv[3]) if len(sys.argv) > 3 else 1
+
+
 def ali_oss():
     try:
         op = sys.argv[2]
@@ -105,15 +138,15 @@ def txcos():
 
 def translate():
     import pyperclip
-    from QuickStart_Rhy.API.Dict import Dict
+    from QuickStart_Rhy.API.TencentTranslate import Translate
 
     content = ' '.join(sys.argv[2:])
     if not content:
         content = pyperclip.paste()
     if content:
         content.replace('\n', ' ')
-        translator = Dict()
-        ret = translator.dictionary(content)
+        translator = Translate()
+        ret = translator.translate(content)
         print(ret if ret else 'Translate Failed!')
     else:
         print("No content in your clipboard or command parameters!")
@@ -154,12 +187,13 @@ def weather():
     table = tls[1].get_res()
     if simple:
         if not loc:
-            from QuickStart_Rhy.API.Dict import Dict
-            translator = Dict()
-            try:
-                trans_loaction = translator.dictionary(simple[0].split('：')[-1])
+            from QuickStart_Rhy.API import pre_check
+            if pre_check("txyun_scid", False) and pre_check("txyun_sckey", False):
+                from QuickStart_Rhy.API.TencentTranslate import Translate
+                translator = Translate()
+                trans_loaction = translator.translate(simple[0].split('：')[-1])
                 print('地区：' + trans_loaction if trans_loaction else simple[0].split('：')[-1])
-            except:
+            else:
                 print('地区：' + simple[0].split('：')[-1])
         simple = simple[2:7]
         print('\n'.join(simple))
@@ -225,3 +259,15 @@ def Seafile_Communicate():
     except IndexError:
         print("Usage:\n  1. qs -sea get\n  2. qs -sea post [msg]")
         exit(0)
+
+
+def Pasteme():
+    from QuickStart_Rhy.API.simple_api import pasteme
+    try:
+        method = sys.argv[2]
+        key = sys.argv[3]
+        password = sys.argv[4] if len(sys.argv) > 4 else ''
+        pasteme(key, password, method)
+    except IndexError:
+        print("Usage:\n  1. qs -pasteme get key [password]\n  2. qs -pasteme post lang [password]")
+        exit(0)
