@@ -37,6 +37,7 @@ def system_menu():
 def net_menu():
     print(color_rep("""Net Tools help:
     qs -http [ip] [-bind url] :-> start a multithread ftp server
+    qs -netinfo [<domains>..] :-> get url's info which in clipboard or params 
     qs -dl [urls]             :-> download file from url(in clipboard)
     qs -upload                :-> upload your pypi library
     qs -upgrade               :-> update qs"""))
@@ -45,15 +46,17 @@ def net_menu():
 def api_menu():
     print(color_rep("""API Tools help:
     qs -trans [content]       :-> translate the content(in clipboard)
-    qs -rmbg <picture>        :-> remove image background
-    qs -smms <picture/*.md>   :-> upload img to smms or all in .md
+    qs -rmbg <img>            :-> remove image background
+    qs -smms <img/*.md>       :-> upload img or img in markdown to sm.ms
+    qs -upimg  -help          :-> upload img or img in markdown to platform
     qs -alioss -help          :-> get aliyun oss api help menu
-    qs -txcos -help           :-> get tencent cos api help menu
-    qs -qiniu -help           :-> get qiniu oss api help menu
+    qs -txcos  -help          :-> get tencent cos api help menu
+    qs -qiniu  -help          :-> get qiniu oss api help menu
     qs -weather [address]     :-> check weather (of address)
     qs -LG <image>            :-> make image larger(with AI)
     qs -nlp [words]           :-> Text(or in clipboard) error correction
-    qs -sea [method] [msg]    :-> Get Or Post msg by Seafile."""))
+    qs -sea <method> [msg]    :-> Get Or Post msg by Seafile.
+    qs -pasteme <method> [*]  :-> get with key, [password] or post clipboard content"""))
 
 
 def image_menu():
@@ -97,21 +100,24 @@ net_funcs = {
     '-http': 'http',
     '-dl': 'download',
     '-upgrade': 'upgrade',
-    '-upload': 'upload_pypi'
+    '-upload': 'upload_pypi',
+    '-netinfo': 'netinfo'
 }
 
 api_funcs = {
     'self': 'api',
     '-trans': 'translate',
     '-rmbg': 'remove_bg',
-    '-smms': 'ImgBed',
+    '-smms': 'smms',
+    '-upimg': 'up_img',
     '-alioss': 'ali_oss',
     '-qiniu': 'qiniu',
     '-txcos': 'txcos',
     '-LG': 'largeImage',
     '-weather': 'weather',
     '-nlp': 'AipNLP',
-    '-sea': 'Seafile_Communicate'
+    '-sea': 'Seafile_Communicate',
+    '-pasteme': 'Pasteme'
 }
 
 image_funcs = {
